@@ -2,7 +2,7 @@ package Email::Send;
 use strict;
 
 use vars qw[$VERSION];
-$VERSION   = '2.199';
+$VERSION   = '2.200';
 
 use Email::Simple 1.92;
 use Module::Pluggable 2.97
@@ -177,7 +177,7 @@ sub send {
 
   my @available = $sender->all_mailers;
 
-Returns a list of availabe mailers. These are mailers that are
+Returns a list of available mailers. These are mailers that are
 installed on your computer and register themselves as available.
 
 =cut
@@ -259,6 +259,7 @@ sub _send_it {
 sub _try_all {
     my ($self, $simple) = @_;
     foreach ( $self->all_mailers ) {
+      next if $_ eq 'Email::Send::Test';
       my $sent = $self->_send_it($_, $simple);
       return $sent if $sent;
     }
