@@ -1,5 +1,4 @@
 use strict;
-use warnings;
 
 package Without;
 
@@ -9,7 +8,7 @@ use File::Temp ();
 use Symbol ();
 
 my $tempdir;
-BEGIN { $tempdir = File::Temp::tempdir(CLEANUP => 1); }
+BEGIN { $tempdir = File::Temp::tempdir(DIR => 't', CLEANUP => 1); }
 use lib $tempdir;
 
 sub import {
